@@ -1,11 +1,14 @@
+//! Items
+//!
+//! This module is incomplete and due to change.
+
+use alloc::string::String;
+
 use serde::{Deserialize, Serialize};
 
 use tinystr::TinyStr16;
 
-use crate::{
-    Dex, Identifiable, IdRef,
-    item::usage::ItemUsage,
-};
+use crate::{item::usage::ItemUsage, Identifiable, Nameable};
 
 pub mod bag;
 pub mod usage;
@@ -13,27 +16,32 @@ pub mod usage;
 mod stack;
 pub use stack::*;
 
+/// An identifier for items.
 pub type ItemId = TinyStr16;
-pub type StackSize = u16;
 
-pub type Itemdex = Dex<Item>;
+pub type Price = u32;
 
-pub type ItemRef<'a> = IdRef<'a, Item>;
-
-#[derive(Debug, Deserialize, Serialize)]
+/// An item.
+#[derive(Debug, Clone, Deserialize, Serialize)]
 #[serde(deny_unknown_fields)]
 pub struct Item {
-    pub id: ItemId,
+    pub id: <Self as Identifiable>::Id,
 
     pub name: String,
-    pub description: Vec<String>,
+    pub description: String,
 
     #[serde(default)]
     pub category: ItemCategory,
 
-    #[serde(default = "Item::default_stack_size")]
-    pub stack_size: StackSize,
+    pub price: Price,
 
+    #[serde(default)]
+    pub stackable: Stackable,
+
+    #[serde(default = "Item::consumable_default")]
+    pub consume: bool,
+
+    /// Item usage (outside of battle)
     #[serde(default)]
     pub usage: ItemUsage,
 }
@@ -41,19 +49,27 @@ pub struct Item {
 impl Identifiable for Item {
     type Id = ItemId;
 
-    const UNKNOWN: Self::Id = crate::id::UNKNOWN_ID;
+    const UNKNOWN: Self::Id = crate::UNKNOWN_ID;
 
     fn id(&self) -> &Self::Id {
         &self.id
     }
 }
 
+impl Nameable for Item {
+    fn name(&self) -> &str {
+        &self.name
+    }
+}
+
 impl Item {
+    pub const fn should_consume(&self) -> bool {
+        self.consume
+    }
 
-    pub const fn default_stack_size() -> StackSize {
-        999
+    const fn consumable_default() -> bool {
+        true
     }
-    
 }
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Deserialize, Serialize)]
@@ -63,8 +79,20 @@ pub enum ItemCategory {
     Pokeballs,
 }
 
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Deserialize, Serialize)]
+pub enum Stackable {
+    Singular,
+    Stackable(u16),
+}
+
+impl Default for Stackable {
+    fn default() -> Self {
+        Self::Stackable(999)
+    }
+}
+
 impl Default for ItemCategory {
     fn default() -> Self {
         Self::Items
     }
-}
\ No newline at end of file
+}
