@@ -1,27 +1,20 @@
+use alloc::vec::Vec;
 use serde::{Deserialize, Serialize};
 
-use crate::{pokemon::Health, ailment::Ailment};
+use crate::{ailment::Ailment, pokemon::Health};
 
 #[derive(Debug, Clone, Default, Deserialize, Serialize)]
 pub struct ItemUsage {
     #[serde(default)]
     pub conditions: Vec<ItemCondition>,
-    #[serde(rename = "type")]
-    pub kind: ItemUsageKind,
-    #[serde(default = "t")]
-    pub consume: bool,
-}
-
-const fn t() -> bool {
-    true
+    pub execute: ItemExecution,
 }
 
 #[derive(Debug, Clone, Deserialize, Serialize)]
 #[serde(deny_unknown_fields)]
-pub enum ItemUsageKind {
+pub enum ItemExecution {
     Actions(Vec<ItemAction>),
-    Script,
-    Pokeball,
+    // Script,
     None,
 }
 
@@ -38,8 +31,8 @@ pub enum ItemAction {
     HealPokemon(Health),
 }
 
-impl Default for ItemUsageKind {
+impl Default for ItemExecution {
     fn default() -> Self {
         Self::None
     }
-}
\ No newline at end of file
+}
