@@ -3,10 +3,11 @@
 //! This module does not contain ways to execute moves, as the [battle](https://crates.io/crates/firecore-battle) crate does this.
 //!
 
+use alloc::string::String;
 use serde::{Deserialize, Serialize};
 use tinystr::TinyStr16;
 
-use crate::{pokemon::stat::StatType, types::PokemonType, Identifiable, UNKNOWN_ID};
+use crate::{pokemon::stat::StatType, types::PokemonType, Identifiable, Nameable, UNKNOWN_ID};
 
 pub mod owned;
 pub mod set;
@@ -58,7 +59,6 @@ pub struct Move {
     /// Increments the chance of whether a move should critical hit or not.
     #[serde(default)]
     pub crit_rate: CriticalRate,
-
 }
 
 impl Identifiable for Move {
@@ -69,11 +69,12 @@ impl Identifiable for Move {
     fn id(&self) -> &Self::Id {
         &self.id
     }
+}
 
+impl Nameable for Move {
     fn name(&self) -> &str {
         &self.name
     }
-
 }
 
 // use MoveCategory::{Physical, Special, Status};
@@ -136,4 +137,4 @@ impl Default for MoveTarget {
     fn default() -> Self {
         Self::None
     }
-}
\ No newline at end of file
+}
